
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

#include "config.h"
/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 114
#define YY_END_OF_BUFFER 115
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1059] =
    {   0,
        1,    1,  115,  112,    1,  113,    2,  112,  107,  108,
      109,  109,  106,   96,  102,   99,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  114,
      114,    1,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
        1,    2,    2,  110,  110,  109,   97,  100,  101,   98,
      112,  112,  112,   92,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,   91,
        0,  111,    1,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

      112,  112,  112,  112,  112,   37,  112,  112,  112,  112,
      112,   93,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,   54,  112,   56,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,    0,    0,    0,    0,    0,   37,
        0,    0,    0,    0,    0,   93,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  112,  112,  112,
      112,  112,  112,   18,  112,  112,   84,  112,  112,  112,

      112,   90,  112,  112,  112,  112,  112,  112,  112,  112,
      112,   78,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,   95,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,   35,   55,  112,  112,  112,  112,  112,  112,
      112,  112,  112,   94,    0,    0,    0,    0,    0,    0,
       18,    0,    0,   84,    0,    0,    0,    0,   90,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   78,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  112,  112,  112,  112,  112,  112,  112,

       19,  112,  112,  112,   29,   81,  112,   17,  112,  112,
      112,  112,  112,   80,  112,  112,  112,  112,   21,  112,
      112,   20,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,   66,
      112,  112,   36,  112,  112,    0,    0,    0,    0,    0,
        0,    0,   19,    0,    0,    0,   29,   81,    0,   17,
        0,    0,    0,    0,    0,   80,    0,    0,    0,    0,
       21,    0,    0,   20,    0,    0,    0,    0,    0,    0,
        0,  112,  105,    0,  112,  112,  112,   30,   19,   19,

      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,   26,  112,   23,  112,
      103,  112,  112,  112,   34,  112,  112,  112,  112,  112,
      112,   64,  112,  112,  112,  112,  112,  112,  112,   31,
      112,  112,  112,  112,  112,  112,  112,  112,  112,    0,
      105,    0,    0,    0,   30,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   26,    0,   23,    0,  103,    0,    0,    0,  112,
        0,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,

      112,  112,   15,  112,  112,   48,   47,  112,  112,  112,
      112,  112,  112,   62,  112,  112,   68,  112,  112,  112,
       32,  112,  112,  112,  112,  112,   57,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   15,
        0,    0,  112,    0,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,   43,   44,   53,  112,

      112,  112,   52,  112,  112,  112,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  112,    0,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,   14,  112,  112,
      112,  112,  112,   25,   24,  112,   22,   16,   83,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,   51,  112,   50,  112,  112,
      112,  112,  112,  112,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,   14,    0,    0,
        0,    0,    0,   25,   24,    0,   22,   16,   83,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   11,    0,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  112,  112,   10,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  112,   49,  112,  112,  112,
      112,   67,  112,  112,  112,  112,  112,   11,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   10,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  112,  112,   74,  112,   73,  112,  112,  112,  112,
       70,  112,  112,  112,   89,   38,  112,  112,  112,   79,
      112,  112,   39,   88,  112,    3,  112,  112,  112,    8,
      112,  112,   46,   45,  112,  112,  112,  112,  112,  112,
      112,    0,    0,   74,    0,   73,    0,    0,    0,    0,
       70,    0,    0,    0,   89,   38,    0,    0,    0,   79,
        0,    0,   39,   88,    0,    3,    0,    0,    0,    8,
        0,    0,    0,  112,  112,  112,  112,  112,  112,  112,
       71,   40,  112,  112,   27,  112,  112,   12,   28,   85,

      112,  112,    4,   86,  112,  112,   58,  112,  112,  112,
      112,    0,    0,    0,    0,    0,    0,    0,   71,   40,
        0,    0,   27,    0,    0,   12,   28,   85,    0,    0,
        4,   86,    0,  112,  112,  112,  112,  112,  112,  112,
      112,   13,  112,   87,  112,  112,  112,  112,  112,  112,
      112,   65,    0,    0,    0,    0,    0,    0,    0,    0,
       13,    0,   87,    0,    0,    0,  112,  112,  112,  112,
      112,  112,  112,  112,   82,  112,  112,  112,  112,   33,
      112,   61,    0,    0,    0,    0,    0,    0,    0,    0,
       82,    0,    0,    0,  112,   77,  112,  112,   41,   42,

       69,  112,  112,    9,  112,   59,  112,    0,   77,    0,
        0,   41,   42,   69,    0,    0,    9,  104,   76,   75,
      112,  112,  112,  112,   60,   76,   75,    0,    0,    0,
      112,  112,  112,   63,    0,    0,    0,   72,    5,    7,
       72,    5,    7,  112,    0,  112,    0,  112,    0,  112,
        0,  112,    0,  112,    0,    6,    6,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    5,    1,    1,    1,    6,
        7,    1,    8,    1,    8,    1,    1,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,   10,    1,   11,
       12,   13,    1,    1,   14,   15,   16,   17,   18,   19,
       20,   21,   22,    1,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,    1,   45,   46,   47,   48,
       49,   50,    1,   51,   52,   53,   54,   55,   56,   57,
       58,   59,   60,    1,   61,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    2,    3,    1,    1,    2,    2,    1,    1,    1,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
        2
    } ;

static yyconst flex_int16_t yy_base[1066] =
    {   0,
        0,   60, 1155,    0, 1152, 1156,   61, 1148, 1156, 1156,
     1143, 1142,    0,   52, 1138, 1137, 1109, 1107,   22, 1100,
     1105,   46,   60, 1090,   48, 1107,   59,   58,   58,   66,
     1156,  126,   68,   69,   66,   68,   71,   79,   88, 1102,
       97,  120,  126, 1087,  125,   81, 1088, 1103,  136,    0,
     1136,  182,    0,    0, 1132, 1127, 1156, 1156, 1156, 1156,
     1096, 1086, 1078,    0, 1080, 1078, 1073, 1090,   80, 1087,
     1081,  133, 1079, 1074,   93, 1082, 1075, 1071, 1081,    0,
       77, 1156,    0,  131,  147, 1071, 1071,  124, 1074,  144,
     1077, 1067,  155,  157, 1061,  158,  142, 1062, 1077,  167,

     1074, 1069, 1058, 1073, 1062, 1053, 1067, 1069,  156,   67,
     1055,    0, 1059, 1044, 1063,  165, 1052, 1048, 1046, 1048,
     1052,  164,  177,  157, 1059, 1041, 1043, 1052, 1045, 1039,
     1045,  176, 1044,    0, 1034,    0, 1046,  229, 1053, 1045,
     1030, 1034, 1028, 1027, 1030, 1038, 1045, 1024, 1035, 1038,
     1030, 1033, 1055, 1022, 1031, 1026, 1015, 1030, 1019, 1010,
     1024, 1026,  172,  182, 1012, 1156, 1016, 1001, 1020,  175,
     1009, 1005, 1003, 1005, 1009,  177,  191,  186, 1016,  998,
     1000, 1009, 1002,  996, 1002,  190, 1001,  999,  999, 1002,
      993,  991, 1002,    0,  996,  984,  996,  196,  991,  986,

      980,    0,  996,  983,  996,  995,  984,  983,  976,  972,
      985,    0,  984,  966,  979,  980,  973,  972,  977,  996,
      961,  964,  967,  970,  972,  957,  969,    0,  972,  958,
      962,  195,  951,  960,  203,  959,  966,  961,  951,  959,
      967,  959,    0,    0,  958,  949,  945,  953,  948,  947,
      937,  964,  939,    0,  942,  942,  945,  936,  934,  945,
     1156,  939,  927,  939,  938,  933,  928,  922, 1156,  938,
      925,  938,  937,  926,  925,  918,  914,  927, 1156,  926,
      908,  921,  922,  915,  914,  919,  938,  903,  906,  909,
      912,  914,  899,  935,  902,  231,  907,  897,  901,  894,

      262,  929,  909,  901,    0,    0,  896,    0,  905,  904,
      890,  885,  897,  917,  227,  886,  899,  887,    0,  886,
      891,    0,  890,  889,  900,  887,  886,  876,  884,  872,
      884,  870,  874,  862,  870,  864,  877,  864,  878,  200,
      867,  855,  885,  862,  856,  865,  853,  862,  884,    0,
      849,  855,    0,  850,  851,  884,  851,  247,  856,  846,
      850,  843,    0,  878,  858,  850, 1156, 1156,  845, 1156,
      854,  853,  839,  834,  846,  866,  234,  835,  848,  836,
     1156,  835,  840, 1156,  839,  838,  849,  836,  835,  825,
      833,  823,    0,  249,  831,  818,  829,    0,  277,    0,

      819,  823,  823,  825,  818,  817,  823,  817,  809,  805,
      814,  808,  800,  811,  814,  804,    0,  799,    0,  802,
        0,  797,  793,  816,    0,  802,  806,  801,  810,  809,
      792,    0,  797,  801,  799,  792,  783,  783,  781,    0,
      783,  802,  780,  791,  790,  810,  789,  785,  768,  776,
     1156,  784,  771,  782, 1156,  772,  776,  776,  778,  771,
      770,  776,  770,  762,  758,  767,  761,  753,  764,  767,
      757, 1156,  752, 1156,  755, 1156,  750,  746,  769,  754,
      759,  324,  758,  781,  750,  756,  741,  761,  738,  737,
      746,  740,  735,  739,  744,  754,  768,  744,  766,  725,

      727,  735,    0,  267,  729,    0,    0,  735,  740,  739,
      720,  723,  723,    0,  731,  730,    0,  722,  724,  729,
        0,  725,  708,  713,  723,  748,    0,  715,  345,  720,
      743,  712,  718,  703,  723,  700,  699,  708,  702,  697,
      701,  706,  716,  730,  706,  728,  687,  689,  697, 1156,
      269,  691,  690,  686,  701,  687,  686,  696,  684,  226,
      683,  687,  686,  693,  684,  674,  680,  676,  682,  707,
      678,  681,  680,  681,  670,  659,  678,  667,  676,  664,
      670,  665,  692,  669,  660,  658,  657,  661,  660,  684,
      659,  655,  654,  646,  645,  641,    0,    0,    0,  648,

      644,  663,    0,  644,  641,  643,  641,  653,  639,  638,
      648,  636,  236,  635,  639,  638,  645,  636,  626,  632,
      628,  634,  659,  630,  633,  632,  633,  622,  611,  630,
      619,  628,  616,  622,  617,  644,  621,  612,  609,  605,
      606,   26,   68,   84,  101,  138,  191,  230,  206,  229,
      219,  229,  233,  227,  239,  248,  254,    0,  259,  253,
      265,  257,  254,    0,    0,  276,    0,    0,    0,  273,
      259,  265,  272,  269,  257,  258,  263,  279,  266,  260,
      267,  277,  271,  271,  272,    0,  313,    0,  286,  285,
      277,  284,  306,  295,  284,  298,  295,  294,  295,  309,

      293,  303,  301,  295,  304,  316,  315, 1156,  321,  315,
      328,  322,  319, 1156, 1156,  342, 1156, 1156, 1156,  339,
      327,  335,  342,  339,  327,  328,  333,  349,  336,  330,
      337,  347,    0,  356,  348,  345,  342,  356,  349,  362,
      365,  366,  357,  362,  357,  350,  366,  368,    0,  354,
      362,  363,  374,  365,  368,  364,  361,  377,  376,  364,
      378,  383,  376,  381,  376,  377,    0,  384,  385,  375,
      391,    0,  378,  378,  399,  390,  412, 1156,  388,  385,
      382,  396,  389,  402,  405,  406,  397,  402,  397,  390,
      406,  408, 1156,  394,  402,  403,  414,  405,  408,  404,

      401,  417,  416,  404,  418,  423,  416,  421,  416,  417,
      422,  449,  415,    0,  451,    0,  422,  433,  434,  418,
        0,  432,  433,  425,    0,    0,  426,  436,  425,    0,
      428,  428,    0,    0,  442,    0,  430,  436,  430,    0,
      444,  445,    0,    0,  444,  434,  435,  445,  452,  474,
      452,  477,  443, 1156,  479, 1156,  450,  461,  462,  446,
     1156,  460,  461,  453, 1156, 1156,  454,  464,  453, 1156,
      456,  456, 1156, 1156,  470, 1156,  458,  464,  458, 1156,
      472,  473,  474,  466,  464,  468,  478,  473,  474,  477,
        0,    0,  466,  472,    0,  479,  472,    0,    0,    0,

      486,  483,    0,    0,  474,  486,    0,  482,  480,  488,
      480,  485,  483,  487,  497,  492,  493,  496, 1156, 1156,
      485,  491, 1156,  498,  491, 1156, 1156, 1156,  505,  502,
     1156, 1156,  545,  502,  509,  504,  519,  498,  499,  505,
      523,    0,  504,    0,  525,  509,  512,  520,  519,  518,
      508,    0,  518,  525,  520,  535,  514,  515,  521,  539,
     1156,  520, 1156,  541,  525,  526,  527,  524,  529,  535,
      540,  541,  534,  539,    0,  540,  538,  547,  537,    0,
      539,    0,  541,  538,  543,  549,  554,  555,  548,  553,
     1156,  554,  551,  559,  550,    0,  551,  550,    0,    0,

        0,  551,  552,    0,  558,    0,  554,  557, 1156,  558,
      557, 1156, 1156, 1156,  558,  559, 1156, 1156,    0,    0,
      567,  568,  569,  563,    0, 1156, 1156,  571,  572,  573,
      580,  581,  582,    0,  583,  584,  585,    0,  607,    0,
     1156,  608, 1156,  577,  578,  581,  582,  585,  586,  620,
      621,  585,  586,  596,  597,    0, 1156, 1156,  639,  640,
      642,  644,  647,  651,  655
    } ;

static yyconst flex_int16_t yy_def[1066] =
    {   0,
     1058,    1, 1058, 1059, 1058, 1058, 1060, 1061, 1058, 1058,
     1059, 1059, 1059, 1058, 1058, 1058, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1062,
     1058, 1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1058, 1060, 1063, 1061, 1061, 1059, 1058, 1058, 1058, 1058,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1062, 1058,   32, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059,

     1064, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1065, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1059, 1059, 1058, 1059, 1059, 1059, 1059, 1064, 1065,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1059,
     1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1059, 1058, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,

     1059, 1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1059, 1058, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058, 1058, 1058,

     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1059, 1058, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,

     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1059, 1059, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059, 1059,
     1059, 1059, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1059, 1059, 1059, 1059, 1059, 1059,

     1059, 1059, 1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1059, 1059,
     1059, 1059, 1059, 1059, 1059, 1058, 1058, 1058, 1058, 1058,
     1059, 1059, 1059, 1059, 1058, 1058, 1058, 1059, 1059, 1059,
     1058, 1058, 1058, 1059, 1058, 1059, 1058, 1059, 1058, 1059,
     1058, 1059, 1058, 1059, 1058, 1059, 1058,    0, 1058, 1058,
     1058, 1058, 1058, 1058, 1058
    } ;

static yyconst flex_int16_t yy_nxt[1218] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,    4,   18,   19,   20,    4,   21,
       22,    4,    4,   23,   24,   25,    4,   26,    4,   27,
       28,   29,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,   30,
       31,   32,   53,   57,   58,   63,   53,   53,   82,  731,
       64,   53,   53,   53,   33,   34,   35,   36,   37,   82,
       38,   39,   40,   41,   42,   67,  732,   43,   44,   68,
       45,   46,   47,   48,   49,   69,   72,   77,   75,   70,

       79,   73,   76,  101,  103,  198,   80,  102,   62,   63,
       78,  104,  199,   65,  106,  107,  108,  105,   67,  109,
       53,   53,  110,   79,  126,  111,   82,   83,  112,   80,
      149,  141,   69,  142,  733,  113,   70,   82,  127,  150,
       84,   85,   86,   87,   88,  115,   89,   90,   91,   92,
       93,  145,  734,   94,   95,  116,   96,   97,   98,   99,
      100,   74,  146,  117,  122,  118,  155,  123,  124,  162,
      156,  130,  163,   71,  119,  735,  120,   78,  131,  132,
      125,  165,  157,   53,  166,  180,  133,   53,   53,  158,
      170,  167,   53,   53,   53,  159,  172,  176,  171,  181,

      177,  178,  184,  196,  215,  173,  197,  174,  204,  185,
      186,  211,  213,  179,  224,  216,  212,  187,  271,  263,
      265,  205,  264,  225,  278,  214,  280,  266,  291,  279,
      334,  272,  394,  282,  240,  303,  736,  292,  335,  281,
      338,   53,   53,  229,  283,  339,  435,  230,  394,  231,
      394,  354,  436,  232,  739,  233,  234,  411,  412,  235,
      236,  651,  237,  400,  466,  467,  740,  400,  400,  652,
      296,  701,  400,  400,  400,  741,  742,  737,  400,  702,
      738,  238,  400,  400,  743,  744,  358,  400,  400,  400,
      586,  745,  639,  746,  587,  481,  640,  588,  589,  641,

      642,  747,  748,  749,  750,  751,  752,  753,  754,  755,
      756,  757,  758,  759,  760,  761,  762,  763,  764,  765,
      766,  400,  400,  767,  768,  769,  770,  772,  773,  774,
      775,  771,  776,  777,  778,  779,  400,  400,  555,  556,
      780,  781,  557,  783,  782,  558,  784,  559,  560,  785,
      786,  561,  787,  788,  562,  563,  789,  564,  565,  608,
      609,  790,  791,  610,  792,  793,  611,  794,  612,  613,
      795,  796,  614,  797,  798,  615,  616,  799,  617,  618,
      800,  801,  802,  803,  804,  805,  806,  807,  808,  809,
      810,  811,  812,  813,  814,  815,  816,  817,  818,  819,

      820,  821,  822,  823,  824,  825,  826,  827,  828,  829,
      830,  831,  832,  833,  834,  835,  836,  837,  838,  839,
      840,  841,  842,  843,  844,  845,  846,  847,  848,  849,
      850,  851,  852,  853,  854,  855,  856,  857,  858,  859,
      860,  861,  862,  863,  864,  865,  866,  867,  868,  869,
      870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
      880,  881,  882,  883,  884,  885,  886,  887,  888,  889,
      890,  891,  892,  893,  894,  895,  896,  897,  898,  899,
      900,  901,  902,  903,  904,  905,  906,  907,  908,  909,
      910,  911,  912,  913,  914,  915,  916,  917,  918,  919,

      920,  921,  922,  923,  924,  925,  926,  927,  928,  929,
      930,  931,  932,  933,  934,  935,  936,  937,  938,  939,
      940,  941,  942,  943,  944,  945,  946,  947,  948,  949,
      950,  951,  952,  953,  954,  955,  956,  957,  958,  959,
      960,  961,  962,  963,  964,  965,  966,  967,  968,  969,
      970,  971,  972,  973,  974,  975,  976,  977,  978,  979,
      980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
      990,  991,  992,  993,  994,  995,  996,  997,  998,  999,
     1000, 1001, 1002, 1003,  933, 1004, 1005, 1006, 1007, 1008,
     1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018,

     1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028,
     1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038,
     1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048,
     1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056, 1057,   50,
       52,   52,   54,   52,   81,   81,   81,   53,   53,  730,
       53,  399,  399,  729,  399,  400,  400,  728,  400,  727,
      726,  725,  724,  723,  722,  721,  720,  719,  718,  717,
      716,  715,  714,  713,  712,  711,  710,  709,  708,  707,
      706,  705,  704,  703,  700,  699,  698,  697,  696,  695,
      694,  693,  692,  691,  690,  689,  688,  687,  686,  685,

      684,  683,  682,  681,  680,  679,  678,  677,  676,  675,
      674,  673,  672,  671,  670,  669,  668,  667,  666,  665,
      664,  663,  662,  661,  660,  659,  658,  657,  656,  655,
      654,  653,  650,  649,  648,  647,  646,  645,  644,  643,
      638,  637,  636,  635,  634,  633,  632,  631,  630,  629,
      628,  627,  626,  625,  624,  623,  622,  621,  620,  619,
      607,  606,  605,  604,  603,  602,  601,  600,  599,  598,
      597,  596,  595,  594,  593,  592,  591,  590,  585,  584,
      583,  582,  581,  580,  579,  578,  577,  576,  575,  574,
      573,  572,  571,  570,  569,  568,  567,  566,  554,  553,

      552,  551,  550,  549,  548,  547,  546,  545,  544,  543,
      542,  541,  540,  539,  538,  537,  536,  535,  534,  533,
      532,  531,  530,  529,  528,  527,  526,  525,  524,  523,
      522,  521,  520,  519,  518,  517,  516,  515,  514,  513,
      512,  511,  510,  509,  508,  507,  506,  505,  504,  503,
      502,  501,  500,  499,  498,  497,  496,  495,  494,  493,
      492,  491,  490,  489,  488,  487,  486,  485,  484,  483,
      482,  480,  479,  478,  477,  476,  475,  474,  473,  472,
      471,  470,  469,  468,  465,  464,  463,  462,  461,  460,
      459,  458,  457,  456,  455,  454,  453,  452,  451,  450,

      449,  448,  447,  446,  445,  444,  443,  442,  441,  440,
      439,  438,  437,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  422,  421,  420,  419,  418,
      417,  416,  415,  414,  413,  410,  409,  408,  407,  406,
      405,  404,  403,  402,  401,  398,  397,  396,  395,  393,
      392,  391,  390,  389,  388,  387,  386,  385,  384,  383,
      382,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  370,  369,  368,  367,  366,  365,  364,  363,
      362,  361,  360,  359,  358,  357,  356,  355,  354,  353,
      352,  351,  350,  349,  348,  347,  346,  345,  344,  343,

      342,  341,  340,  337,  336,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  319,
      318,  317,  316,  315,  314,  313,  312,  311,  310,  309,
      308,  307,  306,  305,  304,  302,  301,  300,  299,  298,
      297,  296,  295,  294,  293,  290,  289,  288,  287,  286,
      285,  284,  277,  276,  275,  274,  273,  270,  269,  268,
      267,  262,  261,  260,  259,  258,  257,  256,  255,  254,
      253,  252,  251,  250,  249,  248,  247,  246,  245,  244,
      243,  242,  241,  240,  239,  228,  227,  226,  223,  222,
      221,  220,  219,  218,  217,  210,  209,  208,  207,  206,

      203,  202,  201,  200,  195,  194,  193,  192,  191,  190,
      189,  188,  183,  182,  175,  169,  168,  164,  161,  160,
      154,  153,  152,  151,  148,  147,  144,  143,  140,  139,
      138,  137,  136,  135,  134,   56,   55,   51,  129,  128,
      121,  114,   74,   71,   66,   65,   62,   61,   60,   59,
       56,   56,   55,   51, 1058,    3, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,

     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058
    } ;

static yyconst flex_int16_t yy_chk[1218] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    7,   14,   14,   19,    7,    7,   30,  642,
       19,    7,    7,    7,    2,    2,    2,    2,    2,   81,
        2,    2,    2,    2,    2,   22,  643,    2,    2,   22,
        2,    2,    2,    2,    2,   23,   25,   28,   27,   23,

       29,   25,   27,   33,   34,  110,   29,   33,   34,   35,
       28,   34,  110,   36,   35,   36,   37,   34,   38,   37,
        7,    7,   38,   46,   46,   39,   30,   32,   39,   46,
       75,   69,   41,   69,  644,   39,   41,   81,   46,   75,
       32,   32,   32,   32,   32,   41,   32,   32,   32,   32,
       32,   72,  645,   32,   32,   42,   32,   32,   32,   32,
       32,   43,   72,   42,   45,   43,   84,   45,   45,   88,
       84,   49,   88,   42,   43,  646,   43,   45,   49,   49,
       45,   90,   85,   52,   90,   97,   49,   52,   52,   85,
       93,   90,   52,   52,   52,   85,   94,   96,   93,   97,

       96,   96,  100,  109,  124,   94,  109,   94,  116,  100,
      100,  122,  123,   96,  132,  124,  122,  100,  170,  163,
      164,  116,  163,  132,  176,  123,  177,  164,  186,  176,
      232,  170,  296,  178,  198,  198,  647,  186,  232,  177,
      235,   52,   52,  138,  178,  235,  340,  138,  358,  138,
      394,  315,  340,  138,  649,  138,  138,  315,  315,  138,
      138,  560,  138,  301,  377,  377,  650,  301,  301,  560,
      296,  613,  301,  301,  301,  651,  652,  648,  399,  613,
      648,  138,  399,  399,  653,  654,  358,  399,  399,  399,
      504,  655,  551,  656,  504,  394,  551,  504,  504,  551,

      551,  657,  659,  660,  661,  662,  663,  666,  670,  671,
      672,  673,  674,  675,  676,  677,  678,  679,  680,  681,
      682,  301,  301,  683,  684,  685,  687,  689,  690,  691,
      692,  687,  693,  694,  695,  696,  399,  399,  482,  482,
      697,  698,  482,  699,  698,  482,  700,  482,  482,  701,
      702,  482,  703,  704,  482,  482,  705,  482,  482,  529,
      529,  706,  707,  529,  709,  710,  529,  711,  529,  529,
      712,  713,  529,  716,  720,  529,  529,  721,  529,  529,
      722,  723,  724,  725,  726,  727,  728,  729,  730,  731,
      732,  734,  735,  736,  737,  738,  739,  740,  741,  742,

      743,  744,  745,  746,  747,  748,  750,  751,  752,  753,
      754,  755,  756,  757,  758,  759,  760,  761,  762,  763,
      764,  765,  766,  768,  769,  770,  771,  773,  774,  775,
      776,  777,  779,  780,  781,  782,  783,  784,  785,  786,
      787,  788,  789,  790,  791,  792,  794,  795,  796,  797,
      798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
      808,  809,  810,  811,  812,  813,  815,  817,  818,  819,
      820,  822,  823,  824,  827,  828,  829,  831,  832,  835,
      837,  838,  839,  841,  842,  845,  846,  847,  848,  849,
      850,  851,  852,  853,  855,  857,  858,  859,  860,  862,

      863,  864,  867,  868,  869,  871,  872,  875,  877,  878,
      879,  881,  882,  883,  884,  885,  886,  887,  888,  889,
      890,  893,  894,  896,  897,  901,  902,  905,  906,  908,
      909,  910,  911,  912,  913,  914,  915,  916,  917,  918,
      921,  922,  924,  925,  929,  930,  933,  934,  935,  936,
      937,  938,  939,  940,  941,  943,  945,  946,  947,  948,
      949,  950,  951,  953,  954,  955,  956,  957,  958,  959,
      960,  962,  964,  965,  966,  967,  968,  969,  970,  971,
      972,  973,  974,  976,  933,  977,  978,  979,  981,  983,
      984,  985,  986,  987,  988,  989,  990,  992,  993,  994,

      995,  997,  998, 1002, 1003, 1005, 1007, 1008, 1010, 1011,
     1015, 1016, 1021, 1022, 1023, 1024, 1028, 1029, 1030, 1031,
     1032, 1033, 1035, 1036, 1037, 1039, 1042, 1044, 1045, 1046,
     1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1059,
     1060, 1060, 1061, 1060, 1062, 1062, 1062, 1063, 1063,  641,
     1063, 1064, 1064,  640, 1064, 1065, 1065,  639, 1065,  638,
      637,  636,  635,  634,  633,  632,  631,  630,  629,  628,
      627,  626,  625,  624,  623,  622,  621,  620,  619,  618,
      617,  616,  615,  614,  612,  611,  610,  609,  608,  607,
      606,  605,  604,  602,  601,  600,  596,  595,  594,  593,

      592,  591,  590,  589,  588,  587,  586,  585,  584,  583,
      582,  581,  580,  579,  578,  577,  576,  575,  574,  573,
      572,  571,  570,  569,  568,  567,  566,  565,  564,  563,
      562,  561,  559,  558,  557,  556,  555,  554,  553,  552,
      549,  548,  547,  546,  545,  544,  543,  542,  541,  540,
      539,  538,  537,  536,  535,  534,  533,  532,  531,  530,
      528,  526,  525,  524,  523,  522,  520,  519,  518,  516,
      515,  513,  512,  511,  510,  509,  508,  505,  502,  501,
      500,  499,  498,  497,  496,  495,  494,  493,  492,  491,
      490,  489,  488,  487,  486,  485,  484,  483,  481,  480,

      479,  478,  477,  475,  473,  471,  470,  469,  468,  467,
      466,  465,  464,  463,  462,  461,  460,  459,  458,  457,
      456,  454,  453,  452,  450,  449,  448,  447,  446,  445,
      444,  443,  442,  441,  439,  438,  437,  436,  435,  434,
      433,  431,  430,  429,  428,  427,  426,  424,  423,  422,
      420,  418,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  405,  404,  403,  402,  401,  397,  396,
      395,  392,  391,  390,  389,  388,  387,  386,  385,  383,
      382,  380,  379,  378,  376,  375,  374,  373,  372,  371,
      369,  366,  365,  364,  362,  361,  360,  359,  357,  356,

      355,  354,  352,  351,  349,  348,  347,  346,  345,  344,
      343,  342,  341,  339,  338,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,
      321,  320,  318,  317,  316,  314,  313,  312,  311,  310,
      309,  307,  304,  303,  302,  300,  299,  298,  297,  295,
      294,  293,  292,  291,  290,  289,  288,  287,  286,  285,
      284,  283,  282,  281,  280,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  268,  267,  266,  265,  264,  263,
      262,  260,  259,  258,  257,  256,  255,  253,  252,  251,
      250,  249,  248,  247,  246,  245,  242,  241,  240,  239,

      238,  237,  236,  234,  233,  231,  230,  229,  227,  226,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  211,  210,  209,  208,  207,  206,  205,
      204,  203,  201,  200,  199,  197,  196,  195,  193,  192,
      191,  190,  189,  188,  187,  185,  184,  183,  182,  181,
      180,  179,  175,  174,  173,  172,  171,  169,  168,  167,
      165,  162,  161,  160,  159,  158,  157,  156,  155,  154,
      153,  152,  151,  150,  149,  148,  147,  146,  145,  144,
      143,  142,  141,  140,  139,  137,  135,  133,  131,  130,
      129,  128,  127,  126,  125,  121,  120,  119,  118,  117,

      115,  114,  113,  111,  108,  107,  106,  105,  104,  103,
      102,  101,   99,   98,   95,   92,   91,   89,   87,   86,
       79,   78,   77,   76,   74,   73,   71,   70,   68,   67,
       66,   65,   63,   62,   61,   56,   55,   51,   48,   47,
       44,   40,   26,   24,   21,   20,   18,   17,   16,   15,
       12,   11,    8,    5,    3, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,

     1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058, 1058,
     1058, 1058, 1058, 1058, 1058, 1058, 1058
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scanner.l"
#line 2 "scanner.l"
/* This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see: <http://www.gnu.org/licenses/>
 */
# include "config.h"
# include "script.h"
# include "types.h"
# include "libs/Parse.h"

/* Suppress definition of yyunput() and yyinput(), as we do not use it. */
#define YY_NO_UNPUT
#define YY_NO_INPUT

int numligne=1;
#line 1100 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 43 "scanner.l"

#line 1290 "lex.yy.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1059 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1156 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 44 "scanner.l"
;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 45 "scanner.l"
;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "scanner.l"
{ return USEGETTEXT; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "scanner.l"
{ return WINDOWTITLE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "scanner.l"
{ return CHWINDOWTITLE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "scanner.l"
{ return CHWINDOWTITLEFARG; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "scanner.l"
{ return WINDOWLOCALETITLE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "scanner.l"
{ return WINDOWSIZE; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "scanner.l"
{ return WINDOWPOSITION; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "scanner.l"
{ return FORECOLOR; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "scanner.l"
{ return BACKCOLOR; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 56 "scanner.l"
{ return SHADCOLOR; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 57 "scanner.l"
{ return LICOLOR; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 58 "scanner.l"
{ return COLORSET; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 59 "scanner.l"
{ return OBJECT; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 60 "scanner.l"
{ return PROP; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "scanner.l"
{ return MAIN; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "scanner.l"
{ return END; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 63 "scanner.l"
{
  char *tmp,*rest;

  rest = GetNextToken(yytext, &tmp); /* skip Font */
  GetNextToken(rest, &yylval.str); /* get the font */
  if (tmp != NULL)
    free(tmp);
  return FONT;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 73 "scanner.l"
{ return TYPE; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 74 "scanner.l"
{ return SIZE; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 75 "scanner.l"
{ return POSITION; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 76 "scanner.l"
{ return VALUE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 77 "scanner.l"
{ return VALUEMIN; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 78 "scanner.l"
{ return VALUEMAX; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 79 "scanner.l"
{ return TITLE; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 80 "scanner.l"
{ return LOCALETITLE; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 81 "scanner.l"
{ return SWALLOWEXEC; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 82 "scanner.l"
{ return ICON; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 83 "scanner.l"
{ return FLAGS; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 84 "scanner.l"
{ return HIDDEN; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 85 "scanner.l"
{ return NOFOCUS; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 86 "scanner.l"
{ return NORELIEFSTRING; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 87 "scanner.l"
{ return CENTER; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 88 "scanner.l"
{ return LEFT; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 89 "scanner.l"
{ return RIGHT; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 91 "scanner.l"
{ return EXEC; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 92 "scanner.l"
{ return HIDE; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 93 "scanner.l"
{ return SHOW; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 94 "scanner.l"
{ return CHVALUE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 95 "scanner.l"
{ return CHVALUEMAX; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 96 "scanner.l"
{ return CHVALUEMIN; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 97 "scanner.l"
{ return GETTITLE; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 98 "scanner.l"
{ return GETVALUE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 99 "scanner.l"
{ return GETMINVALUE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 100 "scanner.l"
{ return GETMAXVALUE; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 101 "scanner.l"
{ return GETFORE; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 102 "scanner.l"
{ return GETBACK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 103 "scanner.l"
{ return GETHILIGHT; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 104 "scanner.l"
{ return GETSHADOW; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 105 "scanner.l"
{ return GETOUTPUT; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 106 "scanner.l"
{ return NUMTOHEX; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 107 "scanner.l"
{ return HEXTONUM; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 108 "scanner.l"
{ return ADD;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 109 "scanner.l"
{ return MULT;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 110 "scanner.l"
{ return DIV;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 111 "scanner.l"
{ return STRCOPY; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 112 "scanner.l"
{ return LAUNCHSCRIPT; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 113 "scanner.l"
{ return GETSCRIPTFATHER; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 114 "scanner.l"
{ return RECEIVFROMSCRIPT; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 115 "scanner.l"
{ return REMAINDEROFDIV; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 116 "scanner.l"
{ return GETTIME; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 117 "scanner.l"
{ return GETSCRIPTARG; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 118 "scanner.l"
{ return GETPID; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 119 "scanner.l"
{ return SENDMSGANDGET; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 120 "scanner.l"
{ return PARSE; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 121 "scanner.l"
{ return LASTSTRING; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 122 "scanner.l"
{ return GETTEXT; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 123 "scanner.l"
{ return POSITION; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 124 "scanner.l"
{ return SIZE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 125 "scanner.l"
{ return TITLE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 126 "scanner.l"
{ return LOCALETITLE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 127 "scanner.l"
{ return ICON; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 128 "scanner.l"
{ return CHFONT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 129 "scanner.l"
{ return CHFORECOLOR; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 130 "scanner.l"
{ return CHBACKCOLOR; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 131 "scanner.l"
{ return CHCOLORSET; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 132 "scanner.l"
{ return SET; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 133 "scanner.l"
{ return SENDSIGN; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 134 "scanner.l"
{ return QUIT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 135 "scanner.l"
{ return INIT; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 136 "scanner.l"
{ return PERIODICTASK; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 137 "scanner.l"
{ return QUITFUNC; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 138 "scanner.l"
{ return FOR; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 139 "scanner.l"
{ return WARP; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 140 "scanner.l"
{ return WRITETOFILE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 141 "scanner.l"
{ return SENDTOSCRIPT; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 142 "scanner.l"
{ return SINGLECLIC; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 143 "scanner.l"
{ return DOUBLECLIC; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 144 "scanner.l"
{ return KEY; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 145 "scanner.l"
{ return TO; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 146 "scanner.l"
{ return DO; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 147 "scanner.l"
{ return IF; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 148 "scanner.l"
{ return THEN; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 149 "scanner.l"
{ return ELSE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 151 "scanner.l"
{ return INF; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 152 "scanner.l"
{ return INFEQ; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 153 "scanner.l"
{ return SUPEQ; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 154 "scanner.l"
{ return SUP; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 155 "scanner.l"
{ return DIFF; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 156 "scanner.l"
{ return EQUAL; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 157 "scanner.l"
{ return GET; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 159 "scanner.l"
{ return WHILE; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 160 "scanner.l"
{ return CASE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 161 "scanner.l"
{ return BEG; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 162 "scanner.l"
{ return POINT; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 163 "scanner.l"
{ return BEGF; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 164 "scanner.l"
{ return ENDF; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 167 "scanner.l"
{ yylval.number=atoi(yytext);
                  return NUMBER;
                }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 171 "scanner.l"
{
		  yylval.str=fxstrdup(yytext + 1);
		  yylval.str[yyleng-1]='\0';
                  return VAR;
		}
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 177 "scanner.l"
{ /* Str entre "" */
		  yylval.str=fxstrdup(yytext + 1);
		  yylval.str[yyleng-2]='\0';
                  return GSTR;
		}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 183 "scanner.l"
{ yylval.str=fxstrdup(yytext);
		  yylval.str[yyleng]='\0';
                  return STR;
		}
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 188 "scanner.l"
{ numligne++; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 189 "scanner.l"
ECHO;
	YY_BREAK
#line 1967 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1059 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1059 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1058);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 189 "scanner.l"
